diff --git a/extras/deploy-scripts/pandora_deploy_community.sh b/extras/deploy-scripts/pandora_deploy_community.sh
index 00c31d911b..7f70addfec 100644
--- a/extras/deploy-scripts/pandora_deploy_community.sh
+++ b/extras/deploy-scripts/pandora_deploy_community.sh
@@ -151,7 +151,7 @@ execute_cmd "yum install -y $extra_repos" "Installing extra repositories"
execute_cmd "yum-config-manager --enable remi-php73" "Configuring PHP"
# Install percona Database
-[ -f /etc/resolv.conf ] && rm -rf /etc/my.cnf
+[ -f /etc/my.cnf ] && rm -rf /etc/my.cnf
execute_cmd "yum install -y Percona-Server-server-57" "Installing Percona Server"
# Console dependencies
@@ -429,6 +429,7 @@ sed -i -e "s/^max_input_time.*/max_input_time = -1/g" /etc/php.ini
sed -i -e "s/^max_execution_time.*/max_execution_time = 0/g" /etc/php.ini
sed -i -e "s/^upload_max_filesize.*/upload_max_filesize = 800M/g" /etc/php.ini
sed -i -e "s/^memory_limit.*/memory_limit = 800M/g" /etc/php.ini
+sed -i -e "s/.*post_max_size =.*/post_max_size = 800M/" /etc/php.ini
cat > /var/www/html/index.html << EOF_INDEX
diff --git a/extras/docker/centos8/pandora-stack/sources/init_pandora.sh b/extras/docker/centos8/pandora-stack/sources/init_pandora.sh
index 7c000ebebd..76a0954bb8 100755
--- a/extras/docker/centos8/pandora-stack/sources/init_pandora.sh
+++ b/extras/docker/centos8/pandora-stack/sources/init_pandora.sh
@@ -149,6 +149,7 @@ EOF_INDEX
sed -i -e "s/^max_execution_time.*/max_execution_time = 0/g" /etc/php.ini
sed -i -e "s/^upload_max_filesize.*/upload_max_filesize = 800M/g" /etc/php.ini
sed -i -e "s/^memory_limit.*/memory_limit = 800M/g" /etc/php.ini
+ sed -i -e "s/.*post_max_size =.*/post_max_size = 800M/" /etc/php.ini
echo "- Setting Public URL: $PUBLICURL"
q=$(mysql -u$DBUSER -p$DBPASS $DBNAME -h$DBHOST -sNe "select token from tconfig;" | grep public_url)
diff --git a/pandora_agents/pc/AIX/pandora_agent.conf b/pandora_agents/pc/AIX/pandora_agent.conf
index b64a2dc4ea..d1f8dd535c 100644
--- a/pandora_agents/pc/AIX/pandora_agent.conf
+++ b/pandora_agents/pc/AIX/pandora_agent.conf
@@ -1,5 +1,5 @@
# Base config file for Pandora FMS agents
-# Version 7.0NG.756, AIX version
+# Version 7.0NG.757, AIX version
# Licensed under GPL license v2,
# Copyright (c) 2003-2021 Artica Soluciones Tecnologicas
# http://www.pandorafms.com
diff --git a/pandora_agents/pc/FreeBSD/pandora_agent.conf b/pandora_agents/pc/FreeBSD/pandora_agent.conf
index 69983a0775..7c663b81e9 100644
--- a/pandora_agents/pc/FreeBSD/pandora_agent.conf
+++ b/pandora_agents/pc/FreeBSD/pandora_agent.conf
@@ -1,5 +1,5 @@
# Base config file for Pandora FMS agents
-# Version 7.0NG.756, FreeBSD Version
+# Version 7.0NG.757, FreeBSD Version
# Licensed under GPL license v2,
# Copyright (c) 2003-2021 Artica Soluciones Tecnologicas
# http://www.pandorafms.com
diff --git a/pandora_agents/pc/HP-UX/pandora_agent.conf b/pandora_agents/pc/HP-UX/pandora_agent.conf
index 2213d2135b..dfe080854a 100644
--- a/pandora_agents/pc/HP-UX/pandora_agent.conf
+++ b/pandora_agents/pc/HP-UX/pandora_agent.conf
@@ -1,5 +1,5 @@
# Base config file for Pandora FMS agents
-# Version 7.0NG.756, HP-UX Version
+# Version 7.0NG.757, HP-UX Version
# Licensed under GPL license v2,
# Copyright (c) 2003-2021 Artica Soluciones Tecnologicas
# http://www.pandorafms.com
diff --git a/pandora_agents/pc/Linux/pandora_agent.conf b/pandora_agents/pc/Linux/pandora_agent.conf
index 559795971f..396dd7f082 100644
--- a/pandora_agents/pc/Linux/pandora_agent.conf
+++ b/pandora_agents/pc/Linux/pandora_agent.conf
@@ -1,5 +1,5 @@
# Base config file for Pandora FMS agents
-# Version 7.0NG.756, GNU/Linux
+# Version 7.0NG.757, GNU/Linux
# Licensed under GPL license v2,
# Copyright (c) 2003-2021 Artica Soluciones Tecnologicas
# http://www.pandorafms.com
diff --git a/pandora_agents/pc/NT4/pandora_agent.conf b/pandora_agents/pc/NT4/pandora_agent.conf
index 96e78f48bd..4430c36487 100644
--- a/pandora_agents/pc/NT4/pandora_agent.conf
+++ b/pandora_agents/pc/NT4/pandora_agent.conf
@@ -1,5 +1,5 @@
# Base config file for Pandora FMS agents
-# Version 7.0NG.756, GNU/Linux
+# Version 7.0NG.757, GNU/Linux
# Licensed under GPL license v2,
# Copyright (c) 2003-2021 Artica Soluciones Tecnologicas
# http://www.pandorafms.com
diff --git a/pandora_agents/pc/SunOS/pandora_agent.conf b/pandora_agents/pc/SunOS/pandora_agent.conf
index 13a72353a0..2056090a48 100644
--- a/pandora_agents/pc/SunOS/pandora_agent.conf
+++ b/pandora_agents/pc/SunOS/pandora_agent.conf
@@ -1,5 +1,5 @@
# Base config file for Pandora FMS agents
-# Version 7.0NG.756, Solaris Version
+# Version 7.0NG.757, Solaris Version
# Licensed under GPL license v2,
# Copyright (c) 2003-2021 Artica Soluciones Tecnologicas
# http://www.pandorafms.com
diff --git a/pandora_agents/pc/Win32/pandora_agent.conf b/pandora_agents/pc/Win32/pandora_agent.conf
index 2f003f7dea..9847836d6e 100644
--- a/pandora_agents/pc/Win32/pandora_agent.conf
+++ b/pandora_agents/pc/Win32/pandora_agent.conf
@@ -1,6 +1,6 @@
# Base config file for Pandora FMS Windows Agent
# (c) 2006-2021 Artica Soluciones Tecnologicas
-# Version 7.0NG.756
+# Version 7.0NG.757
# This program is Free Software, you can redistribute it and/or modify it
# under the terms of the GNU General Public Licence as published by the Free Software
# Foundation; either version 2 of the Licence or any later version
diff --git a/pandora_agents/shellscript/aix/pandora_agent.conf b/pandora_agents/shellscript/aix/pandora_agent.conf
index ce8ee249b5..87b36b2b82 100644
--- a/pandora_agents/shellscript/aix/pandora_agent.conf
+++ b/pandora_agents/shellscript/aix/pandora_agent.conf
@@ -1,6 +1,6 @@
# Fichero de configuracion base de agentes de Pandora
# Base config file for Pandora agents
-# Version 7.0NG.756, AIX version
+# Version 7.0NG.757, AIX version
# General Parameters
# ==================
diff --git a/pandora_agents/shellscript/bsd-ipso/pandora_agent.conf b/pandora_agents/shellscript/bsd-ipso/pandora_agent.conf
index c67b1f7b75..d3ba9de15a 100644
--- a/pandora_agents/shellscript/bsd-ipso/pandora_agent.conf
+++ b/pandora_agents/shellscript/bsd-ipso/pandora_agent.conf
@@ -1,6 +1,6 @@
# Fichero de configuracion base de agentes de Pandora
# Base config file for Pandora agents
-# Version 7.0NG.756
+# Version 7.0NG.757
# FreeBSD/IPSO version
# Licenced under GPL licence, 2003-2007 Sancho Lerena
diff --git a/pandora_agents/shellscript/hp-ux/pandora_agent.conf b/pandora_agents/shellscript/hp-ux/pandora_agent.conf
index 4696abf65e..c61fa634b1 100644
--- a/pandora_agents/shellscript/hp-ux/pandora_agent.conf
+++ b/pandora_agents/shellscript/hp-ux/pandora_agent.conf
@@ -1,6 +1,6 @@
# Fichero de configuracion base de agentes de Pandora
# Base config file for Pandora agents
-# Version 7.0NG.756, HPUX Version
+# Version 7.0NG.757, HPUX Version
# General Parameters
# ==================
diff --git a/pandora_agents/shellscript/linux/pandora_agent.conf b/pandora_agents/shellscript/linux/pandora_agent.conf
index eeacf16b01..0d38a51344 100644
--- a/pandora_agents/shellscript/linux/pandora_agent.conf
+++ b/pandora_agents/shellscript/linux/pandora_agent.conf
@@ -1,5 +1,5 @@
# Base config file for Pandora FMS agents
-# Version 7.0NG.756
+# Version 7.0NG.757
# Licensed under GPL license v2,
# (c) 2003-2021 Artica Soluciones Tecnologicas
# please visit http://pandora.sourceforge.net
diff --git a/pandora_agents/shellscript/mac_osx/pandora_agent.conf b/pandora_agents/shellscript/mac_osx/pandora_agent.conf
index 9574810cdd..014b6bcefe 100644
--- a/pandora_agents/shellscript/mac_osx/pandora_agent.conf
+++ b/pandora_agents/shellscript/mac_osx/pandora_agent.conf
@@ -1,5 +1,5 @@
# Base config file for Pandora FMS agents
-# Version 7.0NG.756
+# Version 7.0NG.757
# Licensed under GPL license v2,
# (c) 2003-2021 Artica Soluciones Tecnologicas
# please visit http://pandora.sourceforge.net
diff --git a/pandora_agents/shellscript/openWRT/pandora_agent.conf b/pandora_agents/shellscript/openWRT/pandora_agent.conf
index 509988935e..25e5e3b6a1 100644
--- a/pandora_agents/shellscript/openWRT/pandora_agent.conf
+++ b/pandora_agents/shellscript/openWRT/pandora_agent.conf
@@ -1,5 +1,5 @@
# Base config file for Pandora FMS agents
-# Version 7.0NG.756
+# Version 7.0NG.757
# Licensed under GPL license v2,
# please visit http://pandora.sourceforge.net
diff --git a/pandora_agents/shellscript/solaris/pandora_agent.conf b/pandora_agents/shellscript/solaris/pandora_agent.conf
index e40edc5de5..2c42b41156 100644
--- a/pandora_agents/shellscript/solaris/pandora_agent.conf
+++ b/pandora_agents/shellscript/solaris/pandora_agent.conf
@@ -1,6 +1,6 @@
# Fichero de configuracion base de agentes de Pandora
# Base config file for Pandora agents
-# Version 7.0NG.756, Solaris version
+# Version 7.0NG.757, Solaris version
# General Parameters
# ==================
diff --git a/pandora_agents/unix/AIX/pandora_agent.conf b/pandora_agents/unix/AIX/pandora_agent.conf
index 8d7610ce47..18bb476835 100644
--- a/pandora_agents/unix/AIX/pandora_agent.conf
+++ b/pandora_agents/unix/AIX/pandora_agent.conf
@@ -1,5 +1,5 @@
# Base config file for Pandora FMS agents
-# Version 7.0NG.756, AIX version
+# Version 7.0NG.757, AIX version
# Licensed under GPL license v2,
# Copyright (c) 2003-2021 Artica Soluciones Tecnologicas
# http://www.pandorafms.com
diff --git a/pandora_agents/unix/DEBIAN/control b/pandora_agents/unix/DEBIAN/control
index 74a7b42af1..ac7e3981fe 100644
--- a/pandora_agents/unix/DEBIAN/control
+++ b/pandora_agents/unix/DEBIAN/control
@@ -1,5 +1,5 @@
package: pandorafms-agent-unix
-Version: 7.0NG.756-210804
+Version: 7.0NG.757-210922
Architecture: all
Priority: optional
Section: admin
diff --git a/pandora_agents/unix/DEBIAN/make_deb_package.sh b/pandora_agents/unix/DEBIAN/make_deb_package.sh
index 1ac2b0219f..e281eaa81d 100644
--- a/pandora_agents/unix/DEBIAN/make_deb_package.sh
+++ b/pandora_agents/unix/DEBIAN/make_deb_package.sh
@@ -14,7 +14,7 @@
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
# GNU General Public License for more details.
-pandora_version="7.0NG.756-210804"
+pandora_version="7.0NG.757-210922"
echo "Test if you has the tools for to make the packages."
whereis dpkg-deb | cut -d":" -f2 | grep dpkg-deb > /dev/null
diff --git a/pandora_agents/unix/Darwin/dmg/build_darwin_dmg.sh b/pandora_agents/unix/Darwin/dmg/build_darwin_dmg.sh
index 9d3ba98b42..dba569f67b 100644
--- a/pandora_agents/unix/Darwin/dmg/build_darwin_dmg.sh
+++ b/pandora_agents/unix/Darwin/dmg/build_darwin_dmg.sh
@@ -31,7 +31,7 @@ fi
if [ "$#" -ge 2 ]; then
VERSION="$2"
else
- VERSION="7.0NG.756"
+ VERSION="7.0NG.757"
fi
# Path for the generated DMG file
diff --git a/pandora_agents/unix/Darwin/dmg/extras/distribution.xml b/pandora_agents/unix/Darwin/dmg/extras/distribution.xml
index 7d83113d91..63cebfdb8b 100644
--- a/pandora_agents/unix/Darwin/dmg/extras/distribution.xml
+++ b/pandora_agents/unix/Darwin/dmg/extras/distribution.xml
@@ -19,11 +19,11 @@
- pandorafms_src.pdk
+ pandorafms_src.pdk
- pandorafms_uninstall.pdk
+ pandorafms_uninstall.pdk
upload (Local)
-conf_ftp_putfile /home/mariopc/Descargas/ejemplo.zip
+conf_ftp_putfile /tmp/test_upload.zip
# Configure name of ftp file --> upload (FTP server)
-conf_ftp_putname prueba.zip
+conf_ftp_putname /tmp/test.zip
# Configure Ip for FTP Connection
conf_ftp_host localhost
# Configure name of ftp file --> download (FTP server)
-conf_ftp_getfile prueba.zip
+conf_ftp_getfile /tmp/test.zip
# Configure complete name os ftp file --> download (Local)
-conf_ftp_getname prueba.zip
+conf_ftp_getname /tmp/test.zip
# Configure Operating System (Unix or Windows)
conf_operating_system Unix
@@ -34,10 +40,10 @@ conf_operating_system Unix
conf_ftp_compare write
-conf_ftp_compare_file prueba.zip
+conf_ftp_compare_file /tmp/prueba.zip
-conf_local_comp_file prueba.zip
+conf_local_comp_file /tmp/prueba.zip
conf_local_downcomp_file /tmp/prueba.zip
diff --git a/pandora_plugins/FTP/ftp_plugin/plugin_ftp.pl b/pandora_plugins/FTP/ftp_plugin/plugin_ftp.pl
index 0aa463e597..e464c42057 100644
--- a/pandora_plugins/FTP/ftp_plugin/plugin_ftp.pl
+++ b/pandora_plugins/FTP/ftp_plugin/plugin_ftp.pl
@@ -8,6 +8,7 @@ use strict;
use warnings;
use Data::Dumper;
use Net::FTP;
+use Net::SFTP::Foreign;
use Time::HiRes qw ( gettimeofday );
my $archivo_cfg = $ARGV[0];
@@ -115,6 +116,14 @@ sub load_external_setup ($)
if ($parametro =~ m/^conf\_ftp\_host\s(.*)/i) {
$plugin_setup{"conf_ftp_host"} = $1;
}
+
+ if ($parametro =~ m/^conf\_ftp\_port\s(.*)/i) {
+ $plugin_setup{"conf_ftp_port"} = $1;
+ }
+
+ if ($parametro =~ m/^conf\_ftp\_sftp\s(.*)/i) {
+ $plugin_setup{"conf_ftp_sftp"} = $1;
+ }
if ($parametro =~ m/^conf\_ftp\_putfile\s(.*)/i) {
$plugin_setup{"conf_ftp_putfile"} = $1;
@@ -184,20 +193,38 @@ load_external_setup ($archivo_cfg);
#-------------------------------------------------------------------------
# Start session in FTP server
#--------------------------------------------------------------------------
-
-my $ftp = Net::FTP->new($plugin_setup{"conf_ftp_host"}) or die("Unable to connect to server: $!");#Connect FTP server
-$ftp->login($plugin_setup{"conf_ftp_user"},$plugin_setup{"conf_ftp_pass"}) or die("Failed Login: $!");# Login at FTP server
+my $ftp;
+if (($plugin_setup{"conf_ftp_sftp"}) && ( $plugin_setup{"conf_ftp_sftp"} == 1)){
+ if ($plugin_setup{"conf_ftp_port"}){
+ #port => $plugin_setup{"port"},
+ $ftp = Net::SFTP::Foreign->new(host => $plugin_setup{"conf_ftp_host"}, port => $plugin_setup{"conf_ftp_port"}, stderr_discard => 1, user => $plugin_setup{"conf_ftp_user"} , password => $plugin_setup{"conf_ftp_pass"},expect_log_user => 'false');
+ if($ftp->error){
+ die($ftp->error);
+ }
+ }else{
+ $ftp = Net::SFTP::Foreign->new(host => $plugin_setup{"conf_ftp_host"}, stderr_discard => 1, user => $plugin_setup{"conf_ftp_user"} , password => $plugin_setup{"conf_ftp_pass"},expect_log_user => 'false');
+ if($ftp->error){
+ die($ftp->error);
+ }
+ }
+} else {
+ if ($plugin_setup{"conf_ftp_port"}){
+ $ftp = Net::FTP->new(host => $plugin_setup{"conf_ftp_host"},port => $plugin_setup{"conf_ftp_port"}) or die("Unable to connect to server: $!");#Connect FTP server
+ }else{
+ $ftp = Net::FTP->new($plugin_setup{"conf_ftp_host"}) or die("Unable to connect to server: $!");#Connect FTP server
+ }
+ $ftp->login($plugin_setup{"conf_ftp_user"},$plugin_setup{"conf_ftp_pass"}) or die("Failed Login: $!");# Login at FTP server
#print_module ( "Disp_FTP_$plugin_setup{conf_ftp_host}" , "generic_proc", 1, " Determines whether FTP login to $plugin_setup{conf_ftp_host} has been successful or not" );
+}
#-------------------------------------------------------------------------
# Returns the module that shows the time and transfer rate.(Upload a file)
#--------------------------------------------------------------------------
my $clock0 = gettimeofday();
- $ftp->put($plugin_setup{"conf_ftp_putfile"},$plugin_setup{"conf_ftp_putname"});# Upload file at FTP server
+ $ftp->put($plugin_setup{"conf_ftp_putfile"},$plugin_setup{"conf_ftp_putname"}) or die("Cannot upload file to server");# Upload file at FTP server
my $clock1 = gettimeofday();
my $clockd = $clock1 - $clock0;# Calculate upload transfer time
- $ftp->size($plugin_setup{"conf_ftp_putname"});# File size
- my $putrate = $ftp->size($plugin_setup{"conf_ftp_putname"})/$clockd;# Calculate rate transfer
+ my $putrate = $ftp->stat($plugin_setup{"conf_ftp_putname"})->size/$clockd;# Calculate rate transfer
my $time_puftp=sprintf("%.2f",$clockd);
my $rate_puftp=sprintf("%.2f",$putrate);
@@ -212,8 +239,8 @@ $ftp->login($plugin_setup{"conf_ftp_user"},$plugin_setup{"conf_ftp_pass"}) or di
$ftp->get($plugin_setup{"conf_ftp_getfile"},$plugin_setup{"conf_ftp_getname"});
my $clock3 = gettimeofday();
my $clockg = $clock3 - $clock2;
- $ftp->size($plugin_setup{"conf_ftp_getname"});
- my $getrate = $ftp->size($plugin_setup{"conf_ftp_getname"})/$clockg;
+ #$ftp->stat($plugin_setup{"conf_ftp_getname"})->size;
+ my $getrate = $ftp->stat($plugin_setup{"conf_ftp_getname"})->size/$clockg;
my $time_getftp=sprintf("%.2f",$clockg);
my $rate_getftp=sprintf("%.2f",$getrate);
diff --git a/pandora_plugins/openstack/.gitignore b/pandora_plugins/openstack/.gitignore
new file mode 100644
index 0000000000..5ceb3864c2
--- /dev/null
+++ b/pandora_plugins/openstack/.gitignore
@@ -0,0 +1 @@
+venv
diff --git a/pandora_plugins/openstack/README b/pandora_plugins/openstack/README
new file mode 100644
index 0000000000..6a963207cc
--- /dev/null
+++ b/pandora_plugins/openstack/README
@@ -0,0 +1,4 @@
+Docu:
+
+EN: https://pandorafms.com/guides/public/books/plugin-openstack-d61
+ES: https://pandorafms.com/guides/public/books/plugin-openstack
\ No newline at end of file
diff --git a/pandora_plugins/openstack/pandora_openstack.py b/pandora_plugins/openstack/pandora_openstack.py
new file mode 100644
index 0000000000..b98c1f5e69
--- /dev/null
+++ b/pandora_plugins/openstack/pandora_openstack.py
@@ -0,0 +1,475 @@
+#!/usr/bin/env python
+# -*- coding: utf-8 -*-
+
+__author__ = "Alejandro Sánchez Carrion"
+__copyright__ = "Copyright 2021, PandoraFMS"
+__maintainer__ = "Projects department"
+__status__ = "Production"
+__version__ = "200721"
+
+import json, requests, argparse, sys
+from datetime import datetime
+
+##Help
+info = f"""
+Pandora FMS Openstack monitoring plugin
+Version = {__version__}
+Description = Connects with digital ocean cloud service an retreave agent data for the instances running.
+
+Execution: { str(sys.argv[0]) } -u -t [ -g ] [ --data_dir ]
+"""
+
+### Variables and arg parser ###
+parser = argparse.ArgumentParser(description= info, formatter_class=argparse.RawTextHelpFormatter)
+parser.add_argument('-u', '--url', help='openstack api keystone url', required=True)
+parser.add_argument('-t', '--token', help='openstack api token', required=True)
+parser.add_argument('-g', '--group', help='PandoraFMS destination group', default='openstack')
+parser.add_argument('--data_dir', help='PandoraFMS data dir (default: /var/spool/pandora/data_in/)', default='/var/spool/pandora/data_in/')
+# parser.add_argument('--prefix', help='Agent prefix, by default openstack_', default='openstack_')
+
+
+args = parser.parse_args()
+
+### Pandora Tools ###
+modules = []
+
+config = {
+ "data_in": args.data_dir,
+ "group" : args.group
+}
+
+def print_agent(agent, modules, prt=1):
+ """Prints agent XML. Requires Agent object as argument."""
+ header = "\n"
+ header += "\n"
+ xml = header
+ for module in modules:
+ modules_xml = print_module(module, 1)
+ xml += str(modules_xml)
+ xml += ""
+ if prt == 2 :
+ print (xml)
+ else :
+ write_xml(xml, agent_name)
+
+def print_module(module, not_print_flag = None):
+ """Returns module in XML format. Accepts only {dict}.\n
+ + Only works with one module at a time: otherwise iteration is needed.
+ + Module "value" field accepts str type or [list] for datalists.
+ + Use not_print_flag to avoid printing the XML (only populates variables).
+ """
+ data = dict(module)
+ module_xml = ("\n"
+ "\t\n"
+ "\t" + str(data["type"]) + "\n"
+ )
+
+ if type(data["type"]) is not str and "string" not in data["type"]: #### Limpia espacios si el módulo no es tipo string
+ data["value"] = data["value"].strip()
+ if isinstance(data["value"], list): # Checks if value is a list
+ module_xml += "\t\n"
+
+ if not not_print_flag:
+ print (module_xml)
+
+ return (module_xml)
+
+def write_xml(xml, agent_name):
+ Utime = datetime.now().strftime('%s')
+ data_file = "%s/%s.%s.data" %(str(config["data_in"]),agent_name,str(Utime))
+ #print (data_file)
+ try :
+ with open(data_file, 'x') as data:
+ data.write(xml)
+ data.close()
+ except OSError as e :
+ pass
+
+
+ return 0
+
+# # default agent
+def clean_agent() :
+ global agent
+ agent = {
+ "agent_name" : "",
+ "agent_alias" : "",
+ "parent_agent_name" : "",
+ "description" : "",
+ "version" : "",
+ "os_name" : "",
+ "os_version" : "",
+ "timestamp" : datetime.today().strftime('%Y/%m/%d %H:%M:%S'),
+ #"utimestamp" : int(datetime.timestamp(datetime.today())),
+ "address" : "127.0.0.1",
+ "group" : config["group"],
+ "interval" : "",
+ }
+ return agent
+
+# default module
+def clean_module() :
+ global modulo
+ modulo = {
+ "name" : "",
+ "type" : "generic_data_string",
+ "desc" : "",
+ "value" : "",
+ }
+ return modulo
+
+
+### MAIN
+#url and token
+
+user_url = args.url
+user_token = args.token
+headers = {
+ 'Content-Type': 'application/json',
+ 'X-Auth-Token': user_token
+}
+
+# request url
+req = {
+ "server": user_url + "/servers",
+ "hypervisors": user_url + "/os-hypervisors/detail"
+}
+try:
+ result = requests.get(req["hypervisors"], headers=headers)
+ result_data = json.loads(result.content)
+except Exception as e :
+ print('0')
+ sys.exit("\nError requesting %s, please check conectivity" %(req["hypervisors"],))
+
+
+for dato in result_data["hypervisors"] :
+ clean_agent()
+ agent.update(
+ agent_name = "Openstack Hypervisor_%s" %(dato['id']),
+ agent_alias = "Openstack Hypervisor_%s" %(dato['id']),
+ description = "Openstack Hypervisor_detailed stats"
+ )
+
+ clean_module()
+ modulo.update(
+ name = "free_disk_gb",
+ desc = "avalaible disk space",
+ value = str(dato['free_disk_gb'])
+ )
+ modules.append(modulo)
+
+ clean_module()
+ modulo.update(
+ name = "free_ram_mb",
+ desc = "available ram ",
+ value = str(dato['free_ram_mb'])
+ )
+ modules.append(modulo)
+
+ clean_module()
+ modulo.update(
+ name = "disk_available_least",
+ desc = "this value is dependent on over committed value of disk, disk_available_least = disk_free_gb - disk_over_committed" ,
+ value = str(dato['disk_available_least'])
+ )
+ modules.append(modulo)
+
+ clean_module()
+ modulo.update(
+ name = "local_gb",
+ desc = "the total available disk for the node's virtual machine, local_gb = local_gb_used + free_disk_gb " ,
+ value = str(dato['local_gb'])
+ )
+ modules.append(modulo)
+
+ clean_module()
+ modulo.update(
+ name = "local_gb_used",
+ desc = "the sum of the node's virtual machine disk ",
+ value = str(dato['local_gb_used'])
+ )
+ modules.append(modulo)
+
+ clean_module()
+ modulo.update(
+ name = "memory_mb",
+ desc = "the total ram of the node, memory_mb_used + free_ram_mb " ,
+ value = str(dato['memory_mb'])
+ )
+ modules.append(modulo)
+
+ clean_module()
+ modulo.update(
+ name = "memory_mb_used",
+ desc = "the sum of the rams of the node's virtual machine " ,
+ value = str(dato['memory_mb_used'])
+ )
+ modules.append(modulo)
+
+ clean_module()
+ modulo.update(
+ name = "vcpus",
+ desc = "node physical cpu total threads ",
+ value = str(dato['vcpus'])
+ )
+ modules.append(modulo)
+
+ clean_module()
+ modulo.update(
+ name = "vcpus_used",
+ desc = "the sum of the vcpus of the node virtual machine ",
+ value = str(dato['vcpus_used'])
+ )
+ modules.append(modulo)
+
+ clean_module()
+ modulo.update(
+ name = "current_workload",
+ desc = "hypervisor current workload " ,
+ value = str(dato['current_workload'])
+ )
+ modules.append(modulo)
+
+ clean_module()
+ modulo.update(
+ name = "host_ip",
+ desc = "hypervisor host ip ",
+ value = str(dato['host_ip'])
+ )
+ modules.append(modulo)
+
+ clean_module()
+ modulo.update(
+ name = "hypervisor_type",
+ desc = "hypervisor type ",
+ value = str(dato['hypervisor_type'])
+ )
+ modules.append(modulo)
+
+ clean_module()
+ modulo.update(
+ name = "hypervisor_version",
+ desc = "hypervisor version ",
+ value = str(dato['hypervisor_version'])
+ )
+ modules.append(modulo)
+
+ clean_module()
+ modulo.update(
+ name = "running_vms",
+ desc = "number of virtual machines running " ,
+ value = str(dato['running_vms'])
+ )
+ modules.append(modulo)
+ print_agent(agent, modules)
+ modules = []
+
+
+try:
+ result = requests.get(req["server"], headers=headers)
+ result_data = json.loads(result.content)
+except Exception as e :
+ print('0')
+ sys.exit("\nError requesting %s, please check conectivity" %(req["server"],))
+
+id_instancia=[]
+
+for dato in result_data["servers"] :
+ id_instancia.append(dato['id'])
+
+for dato in id_instancia:
+ req = {
+ "servers": user_url + "/servers/" + dato + "/diagnostics",
+ "instancia": user_url + "/servers/detail"
+ }
+ # get account data
+ try:
+ result = requests.get(req["servers"], headers=headers)
+ result_data = json.loads(result.content)
+ except Exception as e :
+ print('0')
+ sys.exit("\nError requesting %s, please check conectivity" %(req["servers"],))
+
+ if 'errors' in result_data :
+ print('0')
+ sys.exit(F'Error token, please check token: {result_data}')
+
+
+ clean_agent()
+ agent.update(
+ agent_name = "Openstack instance id: " + dato ,
+ agent_alias ="Openstack instance id: " + dato,
+ description ="Instance metrics"
+ )
+
+ clean_module()
+ modulo.update(
+ name = "memory",
+ type = "generic_data",
+ desc = "memory used by the machine",
+ value = float(result_data['memory']),
+ unit = ""
+ )
+ modules.append(modulo)
+
+ clean_module()
+ modulo.update(
+ name = "memory-actual",
+ type = "generic_data",
+ desc = "memory actual used by the machine",
+ value = float(result_data['memory-actual']),
+ unit = ""
+ )
+ modules.append(modulo)
+
+ clean_module()
+ modulo.update(
+ name = "memory-rss",
+ type = "generic_data",
+ desc = "Resident Set Size and is used to show how much memory is allocated",
+ value = float(result_data['memory-rss']),
+ unit = ""
+ )
+ modules.append(modulo)
+
+ clean_module()
+ modulo.update(
+ name = "vda_errors",
+ type = "generic_data",
+ desc = "diagnostics for a libvirt based instance, vda receibed errors",
+ value = float(result_data['vda_errors']),
+ unit = ""
+ )
+ modules.append(modulo)
+
+ clean_module()
+ modulo.update(
+ name = "vda_read",
+ type = "generic_data",
+ desc = "diagnostics for a libvirt based instance, vda dates read",
+ value = float(result_data['vda_read']),
+ unit = ""
+ )
+ modules.append(modulo)
+
+ clean_module()
+ modulo.update(
+ name = "vda_read_req",
+ type = "generic_data",
+ desc = "diagnostics for a libvirt based instance, vda dates requests read",
+ value = float(result_data['vda_read_req']),
+ unit = ""
+ )
+ modules.append(modulo)
+
+ clean_module()
+ modulo.update(
+ name = "vda_write",
+ type = "generic_data",
+ desc = "diagnostics for a libvirt based instance, vda dates write",
+ value = float(result_data['vda_write']),
+ unit = ""
+ )
+ modules.append(modulo)
+
+ clean_module()
+ modulo.update(
+ name = "vda_write_req",
+ type = "generic_data",
+ desc = "diagnostics for a libvirt based instance, vda write requests dates",
+ value = float(result_data['vda_write_req']),
+ unit = ""
+ )
+ modules.append(modulo)
+ print_agent(agent, modules)
+ modules = []
+
+
+print('1')
\ No newline at end of file
diff --git a/pandora_plugins/openstack/requirements.txt b/pandora_plugins/openstack/requirements.txt
new file mode 100644
index 0000000000..ed92ae5bc8
--- /dev/null
+++ b/pandora_plugins/openstack/requirements.txt
@@ -0,0 +1,5 @@
+certifi==2021.5.30
+charset-normalizer==2.0.4
+idna==3.2
+requests==2.26.0
+urllib3==1.26.6
diff --git a/pandora_server/DEBIAN/control b/pandora_server/DEBIAN/control
index d2a2dbd62d..915a6bb084 100644
--- a/pandora_server/DEBIAN/control
+++ b/pandora_server/DEBIAN/control
@@ -1,5 +1,5 @@
package: pandorafms-server
-Version: 7.0NG.756-210804
+Version: 7.0NG.757-210922
Architecture: all
Priority: optional
Section: admin
diff --git a/pandora_server/DEBIAN/make_deb_package.sh b/pandora_server/DEBIAN/make_deb_package.sh
index 566354a0e2..f77ddeae2d 100644
--- a/pandora_server/DEBIAN/make_deb_package.sh
+++ b/pandora_server/DEBIAN/make_deb_package.sh
@@ -14,7 +14,7 @@
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
# GNU General Public License for more details.
-pandora_version="7.0NG.756-210804"
+pandora_version="7.0NG.757-210922"
package_cpan=0
package_pandora=1
diff --git a/pandora_server/FreeBSD/pandora_server b/pandora_server/FreeBSD/pandora_server
index aa85adc235..c0cea74859 100755
--- a/pandora_server/FreeBSD/pandora_server
+++ b/pandora_server/FreeBSD/pandora_server
@@ -17,6 +17,8 @@
. "/etc/rc.subr"
+PATH=/bin:/usr/bin:/sbin:/usr/sbin:/usr/local/bin
+
name="pandora_ha"
rcvar=pandora_server_enable
diff --git a/pandora_server/FreeBSD/tentacle_server b/pandora_server/FreeBSD/tentacle_server
index db7ad33297..9457d1fe52 100755
--- a/pandora_server/FreeBSD/tentacle_server
+++ b/pandora_server/FreeBSD/tentacle_server
@@ -26,6 +26,8 @@ load_rc_config $name
: ${tentacle_server_config="/usr/local/etc/tentacle/${name}.conf"}
: ${tentacle_server_pidfile="/var/run/${name}.pid"}
+PATH=/bin:/usr/bin:/sbin:/usr/sbin:/usr/local/bin
+
command=/usr/local/bin/${name}
command_interpreter=/usr/local/bin/perl
tentacle_server_user=${tentacle_server_user:-"pandora"}
diff --git a/pandora_server/conf/pandora_server.conf.new b/pandora_server/conf/pandora_server.conf.new
index 2f7ad76aea..d9ea96e6b7 100644
--- a/pandora_server/conf/pandora_server.conf.new
+++ b/pandora_server/conf/pandora_server.conf.new
@@ -1,7 +1,7 @@
#############################################################################
# Pandora FMS Server Parameters
# Pandora FMS, the Flexible Monitoring System.
-# Version 7.0NG.756
+# Version 7.0NG.757
# Licensed under GPL license v2,
# (c) 2003-2021 Artica Soluciones Tecnologicas
# http://www.pandorafms.com
@@ -692,10 +692,10 @@ syslog_max 65535
# Address
# sync_address
-# Pandora FMS Database HA Tool execution interval in seconds (PANDORA FMS ENTERPRISE ONLY).
+# Pandora FMS Daemon Watchdog execution interval in seconds (PANDORA FMS ENTERPRISE ONLY).
ha_interval 30
-# Pandora FMS Database HA Tool monitoring interval in seconds. Must be a multiple of ha_interval (PANDORA FMS ENTERPRISE ONLY).
+# Pandora FMS Daemon Watchdog monitoring interval in seconds. Must be a multiple of ha_interval (PANDORA FMS ENTERPRISE ONLY).
ha_monitoring_interval 60
# Enable (1) or disable (0) Pandora FMS Alert Server.
diff --git a/pandora_server/lib/PandoraFMS/Config.pm b/pandora_server/lib/PandoraFMS/Config.pm
index 52dd5664e2..6bc17f1d9f 100644
--- a/pandora_server/lib/PandoraFMS/Config.pm
+++ b/pandora_server/lib/PandoraFMS/Config.pm
@@ -45,8 +45,8 @@ our @EXPORT = qw(
);
# version: Defines actual version of Pandora Server for this module only
-my $pandora_version = "7.0NG.756";
-my $pandora_build = "210804";
+my $pandora_version = "7.0NG.757";
+my $pandora_build = "210922";
our $VERSION = $pandora_version." ".$pandora_build;
# Setup hash
diff --git a/pandora_server/lib/PandoraFMS/Core.pm b/pandora_server/lib/PandoraFMS/Core.pm
index 014c9952b1..1b98c20783 100644
--- a/pandora_server/lib/PandoraFMS/Core.pm
+++ b/pandora_server/lib/PandoraFMS/Core.pm
@@ -1381,6 +1381,13 @@ sub pandora_execute_action ($$$$$$$$$;$) {
# Address
$field1 = subst_alert_macros ($field1, \%macros, $pa_config, $dbh, $agent, $module, $alert);
+
+ # Simple email address validation. Prevents connections to the SMTP server when no address is provided.
+ if (index($field1, '@') == -1) {
+ logger($pa_config, "No valid email address provided for action '" . $action->{'name'} . "' alert '". $alert->{'name'} . "' agent '" . (defined ($agent) ? $agent->{'alias'} : 'N/A') . "'.", 10);
+ return;
+ }
+
# Subject
$field2 = subst_alert_macros ($field2, \%macros, $pa_config, $dbh, $agent, $module, $alert);
# Message
@@ -1424,11 +1431,11 @@ sub pandora_execute_action ($$$$$$$$$;$) {
my $threshold = shift;
my $period = $hours * 3600; # Hours to seconds
if($threshold == 0){
- $params->{"other"} = $period . '%7C1%7C0%7C225';
+ $params->{"other"} = $period . '%7C1%7C0%7C225%7C""%7C14';
$cid = 'module_graph_' . $hours . 'h';
}
else{
- $params->{"other"} = $period . '%7C1%7C1%7C225';
+ $params->{"other"} = $period . '%7C1%7C1%7C225%7C""%7C14';
$cid = 'module_graphth_' . $hours . 'h';
}
@@ -3683,7 +3690,7 @@ sub pandora_event ($$$$$$$$$$;$$$$$$$$$$$) {
# Create the event
logger($pa_config, "Generating event '$evento' for agent ID $id_agente module ID $id_agentmodule.", 10);
my $event_id = db_insert ($dbh, 'id_evento','INSERT INTO ' . $event_table . ' (id_agente, id_grupo, evento, timestamp, estado, utimestamp, event_type, id_agentmodule, id_alert_am, criticity, user_comment, tags, source, id_extra, id_usuario, critical_instructions, warning_instructions, unknown_instructions, ack_utimestamp, custom_data, data, module_status)
- VALUES (?, ?, ?, ?, ?, ?, ?, ?, ?, ?, ?, ?, ?, ?, ?, ?, ?, ?, ?, ?, ?, ?)', $id_agente, $id_grupo, safe_input ($evento), $timestamp, $event_status, $utimestamp, $event_type, $id_agentmodule, $id_alert_am, $severity, $comment, $module_tags, $source, $id_extra, $user_name, $critical_instructions, $warning_instructions, $unknown_instructions, $ack_utimestamp, $custom_data, $module_data, $module_status);
+ VALUES (?, ?, ?, ?, ?, ?, ?, ?, ?, ?, ?, ?, ?, ?, ?, ?, ?, ?, ?, ?, ?, ?)', $id_agente, $id_grupo, safe_input ($evento), $timestamp, $event_status, $utimestamp, $event_type, $id_agentmodule, $id_alert_am, $severity, $comment, $module_tags, $source, $id_extra, $user_name, $critical_instructions, $warning_instructions, $unknown_instructions, $ack_utimestamp, $custom_data, safe_input($module_data), $module_status);
# Do not write to the event file
return $event_id if ($pa_config->{'event_file'} eq '');
@@ -4828,23 +4835,23 @@ sub generate_status_event ($$$$$$$$) {
}
($event_type, $severity) = ('going_down_normal', 2);
- $description = $pa_config->{"text_going_down_normal"};
+ $description = safe_output($pa_config->{"text_going_down_normal"});
# Critical
} elsif ($status == 1) {
($event_type, $severity) = ('going_up_critical', 4);
- $description = $pa_config->{"text_going_up_critical"};
+ $description = safe_output($pa_config->{"text_going_up_critical"});
# Warning
} elsif ($status == 2) {
# From critical
if ($known_status == 1) {
($event_type, $severity) = ('going_down_warning', 3);
- $description = $pa_config->{"text_going_down_warning"};
+ $description = safe_output($pa_config->{"text_going_down_warning"});
}
# From normal or warning (after becoming unknown)
else {
($event_type, $severity) = ('going_up_warning', 3);
- $description = $pa_config->{"text_going_up_warning"};
+ $description = safe_output($pa_config->{"text_going_up_warning"});
}
} else {
# Unknown status
diff --git a/pandora_server/lib/PandoraFMS/DB.pm b/pandora_server/lib/PandoraFMS/DB.pm
index a25c3e780c..1f53cb228b 100644
--- a/pandora_server/lib/PandoraFMS/DB.pm
+++ b/pandora_server/lib/PandoraFMS/DB.pm
@@ -235,6 +235,9 @@ sub get_console_api_url ($$) {
$pa_config->{"console_api_url"} = 'http://127.0.0.1/pandora_console/' . $include_api;
logger($pa_config, "Assuming default path for API url: " . $pa_config->{"console_api_url"}, 3);
} else {
+ if ($console_api_url !~ /\/$/) {
+ $console_api_url .= '/';
+ }
$pa_config->{"console_api_url"} = $console_api_url . $include_api;
}
}
diff --git a/pandora_server/lib/PandoraFMS/PluginTools.pm b/pandora_server/lib/PandoraFMS/PluginTools.pm
index d10efdf221..c1079c6489 100644
--- a/pandora_server/lib/PandoraFMS/PluginTools.pm
+++ b/pandora_server/lib/PandoraFMS/PluginTools.pm
@@ -33,8 +33,8 @@ use base 'Exporter';
our @ISA = qw(Exporter);
# version: Defines actual version of Pandora Server for this module only
-my $pandora_version = "7.0NG.756";
-my $pandora_build = "210804";
+my $pandora_version = "7.0NG.757";
+my $pandora_build = "210922";
our $VERSION = $pandora_version." ".$pandora_build;
our %EXPORT_TAGS = ( 'all' => [ qw() ] );
diff --git a/pandora_server/pandora_server.redhat.spec b/pandora_server/pandora_server.redhat.spec
index ae91440536..24134d72f5 100644
--- a/pandora_server/pandora_server.redhat.spec
+++ b/pandora_server/pandora_server.redhat.spec
@@ -2,8 +2,8 @@
# Pandora FMS Server
#
%define name pandorafms_server
-%define version 7.0NG.756
-%define release 210804
+%define version 7.0NG.757
+%define release 210922
Summary: Pandora FMS Server
Name: %{name}
diff --git a/pandora_server/pandora_server.spec b/pandora_server/pandora_server.spec
index e9a0b4c296..f25f48510a 100644
--- a/pandora_server/pandora_server.spec
+++ b/pandora_server/pandora_server.spec
@@ -2,8 +2,8 @@
# Pandora FMS Server
#
%define name pandorafms_server
-%define version 7.0NG.756
-%define release 210804
+%define version 7.0NG.757
+%define release 210922
Summary: Pandora FMS Server
Name: %{name}
diff --git a/pandora_server/pandora_server_installer b/pandora_server/pandora_server_installer
index 45b4afb246..ed5929a106 100755
--- a/pandora_server/pandora_server_installer
+++ b/pandora_server/pandora_server_installer
@@ -8,8 +8,8 @@
# This code is licensed under GPL 2.0 license.
# **********************************************************************
-PI_VERSION="7.0NG.756"
-PI_BUILD="210804"
+PI_VERSION="7.0NG.757"
+PI_BUILD="210922"
MODE=$1
if [ $# -gt 1 ]; then
@@ -427,7 +427,7 @@ install () {
[ -d "$SYSTEMD_DIR" ] || mkdir -p "$SYSTEMD_DIR"
cat > $SYSTEMD_DIR/pandora_ha.service <<-EOF
[Unit]
-Description=Pandora FMS Database HA Tool
+Description=Pandora FMS Daemon Watchdog
[Service]
Type=forking
diff --git a/pandora_server/util/pandora_db.pl b/pandora_server/util/pandora_db.pl
index 6117d20220..a326afb7d4 100755
--- a/pandora_server/util/pandora_db.pl
+++ b/pandora_server/util/pandora_db.pl
@@ -35,7 +35,7 @@ use PandoraFMS::Config;
use PandoraFMS::DB;
# version: define current version
-my $version = "7.0NG.756 Build 210804";
+my $version = "7.0NG.757 Build 210922";
# Pandora server configuration
my %conf;
diff --git a/pandora_server/util/pandora_ha.service b/pandora_server/util/pandora_ha.service
index d513572f27..a0324f7ad6 100644
--- a/pandora_server/util/pandora_ha.service
+++ b/pandora_server/util/pandora_ha.service
@@ -1,5 +1,5 @@
[Unit]
-Description=Pandora FMS Database HA Tool
+Description=Pandora FMS Daemon Watchdog
[Service]
Type=forking
diff --git a/pandora_server/util/pandora_manage.pl b/pandora_server/util/pandora_manage.pl
index ce539e29f0..1d478f1b87 100755
--- a/pandora_server/util/pandora_manage.pl
+++ b/pandora_server/util/pandora_manage.pl
@@ -36,7 +36,7 @@ use Encode::Locale;
Encode::Locale::decode_argv;
# version: define current version
-my $version = "7.0NG.756 Build 210804";
+my $version = "7.0NG.757 Build 210922";
# save program name for logging
my $progname = basename($0);
diff --git a/visual_console_client/src/Item.ts b/visual_console_client/src/Item.ts
index cf634da53a..c30c67e73a 100644
--- a/visual_console_client/src/Item.ts
+++ b/visual_console_client/src/Item.ts
@@ -65,6 +65,7 @@ export interface ItemProps extends Position, Size {
aclGroupId: number | null;
cacheExpiration: number | null;
colorStatus: string;
+ cellId: number | null;
}
export interface ItemClickEvent {
@@ -141,6 +142,7 @@ export function itemBasePropsDecoder(data: AnyObject): ItemProps | never {
aclGroupId: parseIntOr(data.aclGroupId, null),
cacheExpiration: parseIntOr(data.cacheExpiration, null),
colorStatus: notEmptyStringOr(data.colorStatus, "#CCC"),
+ cellId: parseIntOr(data.cellId, null),
...sizePropsDecoder(data), // Object spread. It will merge the properties of the two objects.
...positionPropsDecoder(data) // Object spread. It will merge the properties of the two objects.
};
diff --git a/visual_console_client/src/VisualConsole.ts b/visual_console_client/src/VisualConsole.ts
index 1b7288793c..f5b2dfa054 100644
--- a/visual_console_client/src/VisualConsole.ts
+++ b/visual_console_client/src/VisualConsole.ts
@@ -572,6 +572,10 @@ export default class VisualConsole {
Object.keys(this.lineLinks[item.id]).forEach(i => {
let lineId = parseInt(i);
+ const found = this.elementIds.indexOf(lineId);
+ if (found === -1) {
+ return;
+ }
let line = this.elementsById[lineId] as Line;
if (line.props) {
let startX = line.props.startPosition.x;
diff --git a/visual_console_client/src/items/Line.ts b/visual_console_client/src/items/Line.ts
index 2c39a3cb8b..cd58f78a93 100644
--- a/visual_console_client/src/items/Line.ts
+++ b/visual_console_client/src/items/Line.ts
@@ -339,6 +339,10 @@ export default class Line extends Item {
}
protected updateDomElement(element: HTMLElement): void {
+ if (element.parentElement != null) {
+ element.parentElement.style.cursor = "default";
+ }
+
let {
x, // Box x
y, // Box y
@@ -419,6 +423,7 @@ export default class Line extends Item {
startCircle.style.position = "absolute";
startCircle.style.left = `${x1 - this.circleRadius}px`;
startCircle.style.top = `${y1 - this.circleRadius}px`;
+ startCircle.style.cursor = `move`;
endCircle.classList.add(
"visual-console-item-line-circle",
@@ -431,6 +436,7 @@ export default class Line extends Item {
endCircle.style.position = "absolute";
endCircle.style.left = `${x2 - this.circleRadius}px`;
endCircle.style.top = `${y2 - this.circleRadius}px`;
+ endCircle.style.cursor = `move`;
if (element.parentElement !== null) {
const circles = element.parentElement.getElementsByClassName(
diff --git a/visual_console_client/src/items/Odometer.ts b/visual_console_client/src/items/Odometer.ts
index a11f802b9d..159a5a1d16 100644
--- a/visual_console_client/src/items/Odometer.ts
+++ b/visual_console_client/src/items/Odometer.ts
@@ -115,6 +115,12 @@ export default class Odometer extends Item {
"visual-console-container"
) as HTMLElement;
+ if (backgroundColor === null) {
+ backgroundColor = document.getElementById(
+ `visual-console-container-${this.props.cellId}`
+ ) as HTMLElement;
+ }
+
if (backgroundColor.style.backgroundColor == "") {
backgroundColor.style.backgroundColor = "#fff";
}
diff --git a/pandora_server/util/pandora_ha.pl b/pandora_server/util/pandora_ha.pl
index e9631d66c5..ac8774972c 100755
--- a/pandora_server/util/pandora_ha.pl
+++ b/pandora_server/util/pandora_ha.pl
@@ -1,6 +1,6 @@
#!/usr/bin/perl
###############################################################################
# Pandora FMS Database HA
###############################################################################
# Copyright (c) 2018-2021 Artica Soluciones Tecnologicas S.L
###############################################################################
@@ -105,7 +105,7 @@ sub ha_daemonize($) {
sub ha_init_pandora($) {
my $conf = shift;
- log_message($conf, '', "\nPandora FMS Database HA Tool " . $PandoraFMS::Tools::VERSION . " Copyright (c) Artica ST\n");
+ log_message($conf, '', "\nPandora FMS Daemon Watchdog " . $PandoraFMS::Tools::VERSION . " Copyright (c) Artica ST\n");
getopts('dp:', \%Opts);
@@ -171,8 +171,9 @@ sub ha_keep_pandora_running($$) {
'SELECT count(*) AS "delayed"
FROM tserver
WHERE ((status = -1) OR ( (unix_timestamp() - unix_timestamp(keepalive)) > (server_keepalive+1) AND status != 0 ))
- AND server_type != ? AND name = ?',
+ AND server_type NOT IN (?, ?) AND name = ?',
PandoraFMS::Tools::SATELLITESERVER,
+ PandoraFMS::Tools::MFSERVER,
$conf->{'servername'}
);
@@ -1,6 +1,6 @@
#!/usr/bin/perl
###############################################################################
-# Pandora FMS Database HA
+# Pandora FMS Daemon Watchdog
###############################################################################
# Copyright (c) 2018-2021 Artica Soluciones Tecnologicas S.L